import * as _visoning_vue_floating_core from '@visoning/vue-floating-core';
import { FloatingData, FloatingType, ReferenceType, VirtualElement } from '@visoning/vue-floating-core';
export { AutoUpdateOptions, FloatingData, Middleware, MiddlewareData, Placement, Strategy, VirtualElement } from '@visoning/vue-floating-core';
import * as _visoning_vue_utility from '@visoning/vue-utility';
import * as _visoning_vue_floating_interactions from '@visoning/vue-floating-interactions';
import { Delay, BaseInteractionInfo as BaseInteractionInfo$1 } from '@visoning/vue-floating-interactions';
export { InteractorForwardContextValue, createInteractorForwardContext, useInteractorForwardContext } from '@visoning/vue-floating-interactions';
import * as _floating_ui_core from '@floating-ui/core';
import { OffsetOptions, ShiftOptions, FlipOptions, AutoPlacementOptions } from '@floating-ui/core';
import * as vue_demi from 'vue-demi';
import { PropType, VNode, ExtractPropTypes } from 'vue-demi';
import * as _floating_ui_dom from '@floating-ui/dom';
import { AutoUpdateOptions } from '@floating-ui/dom';

interface PopupExposed {
    updatePosition: () => void;
    getFloatingData: () => FloatingData | undefined;
    getElements: () => {
        floating?: FloatingType | undefined | null;
        reference?: ReferenceType | undefined | null;
    };
}
declare type PopupSlotProps = FloatingData;
declare type PopupDelayType = 'open' | 'close';
declare type PopupDelay = Delay | Partial<Record<PopupDelayType, Delay>> | undefined;
declare const PopupPropsType: {
    /**
     * Whether to open popup.
     */
    readonly open: BooleanConstructor;
    /**
     * Default state of open, typically used in uncontrolled mode.
     *
     * @default false
     */
    readonly defaultOpen: BooleanConstructor;
    /**
     * Whether to disable the floating.
     */
    readonly disabled: BooleanConstructor;
    /**
     * You can position a floating element relative to a virtual element instead of a real one.
     * This enables things like positioning context menus or following the cursor.
     * @see https://floating-ui.com/docs/virtual-elements
     */
    readonly virtualElement: PropType<VirtualElement>;
    /**
     * When this value is `true`, popup will be teleport to the target.
     * The teleport to target must be already in the DOM when the <Teleport> component is mounted.
     * @see https://vuejs.org/guide/built-ins/teleport.html
     *
     * Or you can customize the teleport logic, set `appendTo` to false, and use `floatingWrapper`,
     * for simple example
     * @example
     * ```ts
     * {
     *   appendTo: false,
     *   floatingWrapper: (floating) => h(
     *    Teleport,
     *    {
     *      to: anyTarget
     *    },
     *    {
     *      default: () => [floating]
     *    }
     *   )
     * }
     * ```
     *
     * @default 'body'
     */
    readonly appendTo: PropType<string | false | HTMLElement>;
    /**
     * When this value is `false`, even if the popup is closed, floating will update the position as needed,
     * unless popup is disabled.
     */
    readonly autoUpdateOnClosed: BooleanConstructor;
    /**
     * Displaces the popup element from its core placement along the specified axes.
     * @see https://floating-ui.com/docs/offset
     */
    readonly offset: PropType<OffsetOptions>;
    /**
     * Moves the popup element along the specified axes in order to keep it in view.
     * @see https://floating-ui.com/docs/shift
     *
     * @default true
     */
    readonly shift: PropType<boolean | ShiftOptions>;
    /**
     * Changes the placement of the popup element to the opposite one by default in order to keep it in view.
     * @see https://floating-ui.com/docs/flip
     */
    readonly flip: PropType<boolean | FlipOptions>;
    /**
     * Chooses the placement that has the most space available automatically.
     *
     * You’ll want to use this instead of `flip` if you don't want to give the popup element a “preferred” placement
     * and let it choose a placement for you.
     * @see https://floating-ui.com/docs/autoPlacement
     */
    readonly autoPlacement: PropType<boolean | AutoPlacementOptions>;
    /**
     * This determines whether GPU-accelerated styles are used to position the popup.
     * When this value is `true`, popup will use the 3D transforms.
     * When this value is `false`, popup will use top/left properties.
     */
    readonly gpuAcceleration: BooleanConstructor;
    /**
     * Whether destroy popup when closed.
     */
    readonly destoryedOnClosed: BooleanConstructor;
    /**
     * HTML attributes of node.
     */
    readonly floatingProps: PropType<Record<string, any>>;
    /**
     * Custom floating node wrapper.
     * The basic DOM structure is `<Floating/> -> <Popup/> -> <PopupContent/>`.
     */
    readonly floatingWrapper: PropType<(popup: VNode | null) => VNode>;
    /**
     * HTML attributes of node.
     */
    readonly popupProps: PropType<Record<string, any>>;
    /**
     * Custom popup node wrapper.
     * The basic DOM structure is `<Floating/> -> <Popup/> -> <PopupContent/>`.
     */
    readonly popupWrapper: PropType<(popup: VNode | null) => VNode>;
    /**
     * Popup z-index.
     */
    readonly zIndex: NumberConstructor;
    /**
     * Callback on open status changes.
     */
    readonly 'onUpdate:open': PropType<(open: boolean, info: BaseInteractionInfo$1) => void>;
    /**
     * Callback on popup open.
     */
    readonly onOpen: PropType<(info: BaseInteractionInfo$1) => void>;
    /**
     * Callback on popup close.
     */
    readonly onClose: PropType<(info: BaseInteractionInfo$1) => void>;
    readonly delay: PropType<PopupDelay>;
    readonly hoverDelay: PropType<PopupDelay>;
    readonly clickDelay: PropType<PopupDelay>;
    readonly focusDelay: PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {};
    } | {
        type: () => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {}) | (() => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly onFloatingDataUpdate: PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _floating_ui_core.Strategy;
        placement: _floating_ui_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly placement: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Placement & {};
    } | {
        type: () => _floating_ui_core.Placement;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Placement & {}) | (() => _floating_ui_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Strategy & {};
    } | {
        type: () => _floating_ui_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Strategy & {}) | (() => _floating_ui_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: PropType<_floating_ui_core.Middleware[]>;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
};
declare const PopupDefaultProps: {
    readonly open: undefined;
    readonly defaultOpen: false;
    readonly shift: true;
    readonly appendTo: "body";
};
declare const PopupProps: _visoning_vue_utility.WithDefaultProps<{
    /**
     * Whether to open popup.
     */
    readonly open: BooleanConstructor;
    /**
     * Default state of open, typically used in uncontrolled mode.
     *
     * @default false
     */
    readonly defaultOpen: BooleanConstructor;
    /**
     * Whether to disable the floating.
     */
    readonly disabled: BooleanConstructor;
    /**
     * You can position a floating element relative to a virtual element instead of a real one.
     * This enables things like positioning context menus or following the cursor.
     * @see https://floating-ui.com/docs/virtual-elements
     */
    readonly virtualElement: PropType<VirtualElement>;
    /**
     * When this value is `true`, popup will be teleport to the target.
     * The teleport to target must be already in the DOM when the <Teleport> component is mounted.
     * @see https://vuejs.org/guide/built-ins/teleport.html
     *
     * Or you can customize the teleport logic, set `appendTo` to false, and use `floatingWrapper`,
     * for simple example
     * @example
     * ```ts
     * {
     *   appendTo: false,
     *   floatingWrapper: (floating) => h(
     *    Teleport,
     *    {
     *      to: anyTarget
     *    },
     *    {
     *      default: () => [floating]
     *    }
     *   )
     * }
     * ```
     *
     * @default 'body'
     */
    readonly appendTo: PropType<string | false | HTMLElement>;
    /**
     * When this value is `false`, even if the popup is closed, floating will update the position as needed,
     * unless popup is disabled.
     */
    readonly autoUpdateOnClosed: BooleanConstructor;
    /**
     * Displaces the popup element from its core placement along the specified axes.
     * @see https://floating-ui.com/docs/offset
     */
    readonly offset: PropType<OffsetOptions>;
    /**
     * Moves the popup element along the specified axes in order to keep it in view.
     * @see https://floating-ui.com/docs/shift
     *
     * @default true
     */
    readonly shift: PropType<boolean | ShiftOptions>;
    /**
     * Changes the placement of the popup element to the opposite one by default in order to keep it in view.
     * @see https://floating-ui.com/docs/flip
     */
    readonly flip: PropType<boolean | FlipOptions>;
    /**
     * Chooses the placement that has the most space available automatically.
     *
     * You’ll want to use this instead of `flip` if you don't want to give the popup element a “preferred” placement
     * and let it choose a placement for you.
     * @see https://floating-ui.com/docs/autoPlacement
     */
    readonly autoPlacement: PropType<boolean | AutoPlacementOptions>;
    /**
     * This determines whether GPU-accelerated styles are used to position the popup.
     * When this value is `true`, popup will use the 3D transforms.
     * When this value is `false`, popup will use top/left properties.
     */
    readonly gpuAcceleration: BooleanConstructor;
    /**
     * Whether destroy popup when closed.
     */
    readonly destoryedOnClosed: BooleanConstructor;
    /**
     * HTML attributes of node.
     */
    readonly floatingProps: PropType<Record<string, any>>;
    /**
     * Custom floating node wrapper.
     * The basic DOM structure is `<Floating/> -> <Popup/> -> <PopupContent/>`.
     */
    readonly floatingWrapper: PropType<(popup: VNode | null) => VNode>;
    /**
     * HTML attributes of node.
     */
    readonly popupProps: PropType<Record<string, any>>;
    /**
     * Custom popup node wrapper.
     * The basic DOM structure is `<Floating/> -> <Popup/> -> <PopupContent/>`.
     */
    readonly popupWrapper: PropType<(popup: VNode | null) => VNode>;
    /**
     * Popup z-index.
     */
    readonly zIndex: NumberConstructor;
    /**
     * Callback on open status changes.
     */
    readonly 'onUpdate:open': PropType<(open: boolean, info: BaseInteractionInfo$1) => void>;
    /**
     * Callback on popup open.
     */
    readonly onOpen: PropType<(info: BaseInteractionInfo$1) => void>;
    /**
     * Callback on popup close.
     */
    readonly onClose: PropType<(info: BaseInteractionInfo$1) => void>;
    readonly delay: PropType<PopupDelay>;
    readonly hoverDelay: PropType<PopupDelay>;
    readonly clickDelay: PropType<PopupDelay>;
    readonly focusDelay: PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {};
    } | {
        type: () => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {}) | (() => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly onFloatingDataUpdate: PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _floating_ui_core.Strategy;
        placement: _floating_ui_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly placement: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Placement & {};
    } | {
        type: () => _floating_ui_core.Placement;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Placement & {}) | (() => _floating_ui_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Strategy & {};
    } | {
        type: () => _floating_ui_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Strategy & {}) | (() => _floating_ui_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: PropType<_floating_ui_core.Middleware[]>;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
}, {
    readonly open: undefined;
    readonly defaultOpen: false;
    readonly shift: true;
    readonly appendTo: "body";
}>;
declare type PopupProps = ExtractPropTypes<typeof PopupProps>;

declare const Popup: vue_demi.DefineComponent<_visoning_vue_utility.WithDefaultProps<{
    readonly open: BooleanConstructor;
    readonly defaultOpen: BooleanConstructor;
    readonly disabled: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: vue_demi.PropType<string | false | HTMLElement>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly shift: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly popupProps: vue_demi.PropType<Record<string, any>>;
    readonly popupWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: BaseInteractionInfo$1<string, Event>) => void>;
    readonly onOpen: vue_demi.PropType<(info: BaseInteractionInfo$1<string, Event>) => void>;
    readonly onClose: vue_demi.PropType<(info: BaseInteractionInfo$1<string, Event>) => void>;
    readonly delay: vue_demi.PropType<PopupDelay>;
    readonly hoverDelay: vue_demi.PropType<PopupDelay>;
    readonly clickDelay: vue_demi.PropType<PopupDelay>;
    readonly focusDelay: vue_demi.PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {};
    } | {
        type: () => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {}) | (() => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _visoning_vue_floating_core.Strategy;
        placement: _visoning_vue_floating_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly placement: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Placement & {};
    } | {
        type: () => _visoning_vue_floating_core.Placement;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Placement & {}) | (() => _visoning_vue_floating_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Strategy & {};
    } | {
        type: () => _visoning_vue_floating_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Strategy & {}) | (() => _visoning_vue_floating_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_visoning_vue_floating_core.Middleware[]>;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
}, {
    readonly open: undefined;
    readonly defaultOpen: false;
    readonly shift: true;
    readonly appendTo: "body";
}>, () => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue_demi.ComponentOptionsMixin, vue_demi.ComponentOptionsMixin, {}, string, vue_demi.VNodeProps & vue_demi.AllowedComponentProps & vue_demi.ComponentCustomProps, Readonly<ExtractPropTypes<_visoning_vue_utility.WithDefaultProps<{
    readonly open: BooleanConstructor;
    readonly defaultOpen: BooleanConstructor;
    readonly disabled: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: vue_demi.PropType<string | false | HTMLElement>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly shift: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly popupProps: vue_demi.PropType<Record<string, any>>;
    readonly popupWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: BaseInteractionInfo$1<string, Event>) => void>;
    readonly onOpen: vue_demi.PropType<(info: BaseInteractionInfo$1<string, Event>) => void>;
    readonly onClose: vue_demi.PropType<(info: BaseInteractionInfo$1<string, Event>) => void>;
    readonly delay: vue_demi.PropType<PopupDelay>;
    readonly hoverDelay: vue_demi.PropType<PopupDelay>;
    readonly clickDelay: vue_demi.PropType<PopupDelay>;
    readonly focusDelay: vue_demi.PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {};
    } | {
        type: () => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]) & {}) | (() => false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _visoning_vue_floating_core.Strategy;
        placement: _visoning_vue_floating_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly placement: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Placement & {};
    } | {
        type: () => _visoning_vue_floating_core.Placement;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Placement & {}) | (() => _visoning_vue_floating_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Strategy & {};
    } | {
        type: () => _visoning_vue_floating_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Strategy & {}) | (() => _visoning_vue_floating_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_visoning_vue_floating_core.Middleware[]>;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
}, {
    readonly open: undefined;
    readonly defaultOpen: false;
    readonly shift: true;
    readonly appendTo: "body";
}>>>, {
    readonly shift: boolean | _floating_ui_core.ShiftOptions;
    readonly placement: _visoning_vue_floating_core.Placement;
    readonly strategy: _visoning_vue_floating_core.Strategy;
    readonly disabled: boolean;
    readonly autoUpdate: boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    readonly interactions: false | _visoning_vue_floating_interactions.Interaction | _visoning_vue_floating_interactions.Interaction[];
    readonly allowPointerEnterTarget: boolean;
    readonly inactiveWhenClickOutside: boolean;
    readonly open: boolean;
    readonly defaultOpen: boolean;
    readonly appendTo: string | false | HTMLElement;
    readonly autoUpdateOnClosed: boolean;
    readonly gpuAcceleration: boolean;
    readonly destoryedOnClosed: boolean;
}>;

declare type UseAutoUpdateOptions = Partial<AutoUpdateOptions> & {
    /**
     * @default false
     */
    disabled?: boolean;
};

interface BaseInteractionInfo<T extends string = string, U = Event> {
    type: T;
    event?: U | null;
}

declare type Interaction = 'hover' | 'click' | 'focus';

interface PopoverExposed extends PopupExposed {
}
declare type PopoverArrowSlotProps = FloatingData;
declare type CreateArrow = (props: PopoverArrowSlotProps) => VNode | null;
declare const PopoverPropsType: {
    /**
     * support: string | () => VNode | slot
     */
    readonly title: PropType<string | (() => VNode)>;
    /**
     * support: string | () => VNode | slot
     */
    readonly content: PropType<string | (() => VNode)>;
    /**
     * The theme of the popover.
     * @default 'light'
     */
    readonly theme: PropType<"dark" | "light">;
    /**
     * The size of the popover.
     * @default 'meduim'
     */
    readonly size: PropType<"small" | "meduim">;
    /**
     * @see https://cn.vuejs.org/guide/built-ins/transition.html
     */
    readonly transitionProps: PropType<string | Record<string, any>>;
    /**
     * Whether to show arrow if set.
     * @default true
     */
    readonly showArrow: BooleanConstructor;
    /**
     * For style uniformity, we will never enable the configuration of arrow middleware,
     * you can customize arrow to make arrow more as expected.
     *
     * support: CreateArrow | slot
     */
    readonly arrow: PropType<CreateArrow>;
    /**
     * HTML attributes of node.
     */
    readonly arrowProps: PropType<Record<string, any>>;
    /**
     * HTML attributes of popover node.
     */
    readonly popoverProps: PropType<Record<string, any>>;
    /**
     * HTML attributes of popover-content node.
     */
    readonly contentProps: PropType<Record<string, any>>;
    /**
     * Custom popover node wrapper.
     */
    readonly popoverWrapper: PropType<(popup: VNode | null) => VNode>;
    readonly onFloatingDataUpdate: PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _visoning_vue_floating_core.Strategy;
        placement: _visoning_vue_floating_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Placement & {};
    } | {
        type: () => _visoning_vue_floating_core.Placement;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Placement & {}) | (() => _visoning_vue_floating_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Strategy & {};
    } | {
        type: () => _visoning_vue_floating_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Strategy & {}) | (() => _visoning_vue_floating_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: PropType<_visoning_vue_floating_core.Middleware[]>;
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: PropType<PopupDelay>;
    readonly clickDelay: PropType<PopupDelay>;
    readonly focusDelay: PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
};
declare const PopoverTransitionName = "visoning-popover";
declare const PopoverDefaultProps: {
    readonly theme: "line";
    readonly size: "meduim";
    readonly transitionProps: "visoning-popover";
    readonly showArrow: true;
};
declare const PopoverProps: _visoning_vue_utility.WithDefaultProps<{
    /**
     * support: string | () => VNode | slot
     */
    readonly title: PropType<string | (() => VNode)>;
    /**
     * support: string | () => VNode | slot
     */
    readonly content: PropType<string | (() => VNode)>;
    /**
     * The theme of the popover.
     * @default 'light'
     */
    readonly theme: PropType<"dark" | "light">;
    /**
     * The size of the popover.
     * @default 'meduim'
     */
    readonly size: PropType<"small" | "meduim">;
    /**
     * @see https://cn.vuejs.org/guide/built-ins/transition.html
     */
    readonly transitionProps: PropType<string | Record<string, any>>;
    /**
     * Whether to show arrow if set.
     * @default true
     */
    readonly showArrow: BooleanConstructor;
    /**
     * For style uniformity, we will never enable the configuration of arrow middleware,
     * you can customize arrow to make arrow more as expected.
     *
     * support: CreateArrow | slot
     */
    readonly arrow: PropType<CreateArrow>;
    /**
     * HTML attributes of node.
     */
    readonly arrowProps: PropType<Record<string, any>>;
    /**
     * HTML attributes of popover node.
     */
    readonly popoverProps: PropType<Record<string, any>>;
    /**
     * HTML attributes of popover-content node.
     */
    readonly contentProps: PropType<Record<string, any>>;
    /**
     * Custom popover node wrapper.
     */
    readonly popoverWrapper: PropType<(popup: VNode | null) => VNode>;
    readonly onFloatingDataUpdate: PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _visoning_vue_floating_core.Strategy;
        placement: _visoning_vue_floating_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Placement & {};
    } | {
        type: () => _visoning_vue_floating_core.Placement;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Placement & {}) | (() => _visoning_vue_floating_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Strategy & {};
    } | {
        type: () => _visoning_vue_floating_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Strategy & {}) | (() => _visoning_vue_floating_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: PropType<_visoning_vue_floating_core.Middleware[]>;
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: PropType<PopupDelay>;
    readonly clickDelay: PropType<PopupDelay>;
    readonly focusDelay: PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
}, {
    readonly theme: "line";
    readonly size: "meduim";
    readonly transitionProps: "visoning-popover";
    readonly showArrow: true;
}>;
declare type PopoverProps = ExtractPropTypes<typeof PopoverProps>;

declare const classNames$1: {
    popover: string;
    content: string;
    title: string;
    arrow: string;
    dark: string;
};
declare const Popover: vue_demi.DefineComponent<_visoning_vue_utility.WithDefaultProps<{
    readonly title: vue_demi.PropType<string | (() => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly content: vue_demi.PropType<string | (() => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly theme: vue_demi.PropType<"dark" | "light">;
    readonly size: vue_demi.PropType<"small" | "meduim">;
    readonly transitionProps: vue_demi.PropType<string | Record<string, any>>;
    readonly showArrow: BooleanConstructor;
    readonly arrow: vue_demi.PropType<CreateArrow>;
    readonly arrowProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverProps: vue_demi.PropType<Record<string, any>>;
    readonly contentProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _floating_ui_dom.Strategy;
        placement: _floating_ui_dom.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_dom.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_dom.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _floating_ui_dom.Placement & {};
    } | {
        type: () => _floating_ui_dom.Placement;
    } | {
        type: ((new (...args: any[]) => _floating_ui_dom.Placement & {}) | (() => _floating_ui_dom.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _floating_ui_dom.Strategy & {};
    } | {
        type: () => _floating_ui_dom.Strategy;
    } | {
        type: ((new (...args: any[]) => _floating_ui_dom.Strategy & {}) | (() => _floating_ui_dom.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core.Middleware[]>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {}) | (() => boolean | UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: vue_demi.PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: vue_demi.PropType<PopupDelay>;
    readonly clickDelay: vue_demi.PropType<PopupDelay>;
    readonly focusDelay: vue_demi.PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: vue_demi.PropType<_floating_ui_dom.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
}, {
    readonly theme: "line";
    readonly size: "meduim";
    readonly transitionProps: "visoning-popover";
    readonly showArrow: true;
}>, () => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue_demi.ComponentOptionsMixin, vue_demi.ComponentOptionsMixin, {}, string, vue_demi.VNodeProps & vue_demi.AllowedComponentProps & vue_demi.ComponentCustomProps, Readonly<vue_demi.ExtractPropTypes<_visoning_vue_utility.WithDefaultProps<{
    readonly title: vue_demi.PropType<string | (() => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly content: vue_demi.PropType<string | (() => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly theme: vue_demi.PropType<"dark" | "light">;
    readonly size: vue_demi.PropType<"small" | "meduim">;
    readonly transitionProps: vue_demi.PropType<string | Record<string, any>>;
    readonly showArrow: BooleanConstructor;
    readonly arrow: vue_demi.PropType<CreateArrow>;
    readonly arrowProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverProps: vue_demi.PropType<Record<string, any>>;
    readonly contentProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _floating_ui_dom.Strategy;
        placement: _floating_ui_dom.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_dom.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_dom.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _floating_ui_dom.Placement & {};
    } | {
        type: () => _floating_ui_dom.Placement;
    } | {
        type: ((new (...args: any[]) => _floating_ui_dom.Placement & {}) | (() => _floating_ui_dom.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _floating_ui_dom.Strategy & {};
    } | {
        type: () => _floating_ui_dom.Strategy;
    } | {
        type: ((new (...args: any[]) => _floating_ui_dom.Strategy & {}) | (() => _floating_ui_dom.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core.Middleware[]>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {}) | (() => boolean | UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: vue_demi.PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: vue_demi.PropType<PopupDelay>;
    readonly clickDelay: vue_demi.PropType<PopupDelay>;
    readonly focusDelay: vue_demi.PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: vue_demi.PropType<_floating_ui_dom.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
}, {
    readonly theme: "line";
    readonly size: "meduim";
    readonly transitionProps: "visoning-popover";
    readonly showArrow: true;
}>>>, {
    readonly shift: boolean | _floating_ui_core.ShiftOptions;
    readonly placement: _floating_ui_dom.Placement;
    readonly strategy: _floating_ui_dom.Strategy;
    readonly disabled: boolean;
    readonly autoUpdate: boolean | UseAutoUpdateOptions;
    readonly interactions: false | Interaction | Interaction[];
    readonly allowPointerEnterTarget: boolean;
    readonly inactiveWhenClickOutside: boolean;
    readonly open: boolean;
    readonly defaultOpen: boolean;
    readonly appendTo: string | false | HTMLElement;
    readonly autoUpdateOnClosed: boolean;
    readonly gpuAcceleration: boolean;
    readonly destoryedOnClosed: boolean;
    readonly theme: "dark" | "light";
    readonly size: "small" | "meduim";
    readonly transitionProps: string | Record<string, any>;
    readonly showArrow: boolean;
}>;

declare const classNames: {
    tooltip: string;
    content: string;
};
declare const Tooltip: vue_demi.DefineComponent<_visoning_vue_utility.WithDefaultProps<{
    readonly textAlign: vue_demi.PropType<"right" | "left" | "start" | "end" | "center" | "justify" | "match-parent">;
    readonly tooltipProps: vue_demi.PropType<Record<string, any>>;
    readonly tooltipWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _floating_ui_core.Strategy;
        placement: _floating_ui_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Placement & {};
    } | {
        type: () => _floating_ui_core.Placement;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Placement & {}) | (() => _floating_ui_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Strategy & {};
    } | {
        type: () => _floating_ui_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Strategy & {}) | (() => _floating_ui_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core.Middleware[]>;
    readonly arrow: vue_demi.PropType<CreateArrow>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {}) | (() => boolean | UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: vue_demi.PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: vue_demi.PropType<PopupDelay>;
    readonly clickDelay: vue_demi.PropType<PopupDelay>;
    readonly focusDelay: vue_demi.PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: vue_demi.PropType<_floating_ui_dom.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly content: vue_demi.PropType<string | (() => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly theme: Omit<{
        type: new (...args: any[]) => ("dark" | "light") & {};
    } | {
        type: () => "dark" | "light";
    } | {
        type: ((new (...args: any[]) => ("dark" | "light") & {}) | (() => "dark" | "light"))[];
    }, "default"> & {
        default: "line";
    };
    readonly size: Omit<{
        type: new (...args: any[]) => ("small" | "meduim") & {};
    } | {
        type: () => "small" | "meduim";
    } | {
        type: ((new (...args: any[]) => ("small" | "meduim") & {}) | (() => "small" | "meduim"))[];
    }, "default"> & {
        default: "meduim";
    };
    readonly transitionProps: Omit<{
        type: new (...args: any[]) => (string | Record<string, any>) & {};
    } | {
        type: () => string | Record<string, any>;
    } | {
        type: ((new (...args: any[]) => (string | Record<string, any>) & {}) | (() => string | Record<string, any>))[];
    }, "default"> & {
        default: "visoning-popover";
    };
    readonly showArrow: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly arrowProps: vue_demi.PropType<Record<string, any>>;
    readonly contentProps: vue_demi.PropType<Record<string, any>>;
}, {
    readonly interactions: "hover";
    readonly theme: "drak";
    readonly textAlign: "start";
    readonly allowPointerEnterTarget: false;
}>, () => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue_demi.ComponentOptionsMixin, vue_demi.ComponentOptionsMixin, {}, string, vue_demi.VNodeProps & vue_demi.AllowedComponentProps & vue_demi.ComponentCustomProps, Readonly<vue_demi.ExtractPropTypes<_visoning_vue_utility.WithDefaultProps<{
    readonly textAlign: vue_demi.PropType<"right" | "left" | "start" | "end" | "center" | "justify" | "match-parent">;
    readonly tooltipProps: vue_demi.PropType<Record<string, any>>;
    readonly tooltipWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _floating_ui_core.Strategy;
        placement: _floating_ui_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _floating_ui_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: vue_demi.PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Placement & {};
    } | {
        type: () => _floating_ui_core.Placement;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Placement & {}) | (() => _floating_ui_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _floating_ui_core.Strategy & {};
    } | {
        type: () => _floating_ui_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _floating_ui_core.Strategy & {}) | (() => _floating_ui_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core.Middleware[]>;
    readonly arrow: vue_demi.PropType<CreateArrow>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | UseAutoUpdateOptions) & {}) | (() => boolean | UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: vue_demi.PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: vue_demi.PropType<PopupDelay>;
    readonly clickDelay: vue_demi.PropType<PopupDelay>;
    readonly focusDelay: vue_demi.PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: vue_demi.PropType<_floating_ui_dom.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly content: vue_demi.PropType<string | (() => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly theme: Omit<{
        type: new (...args: any[]) => ("dark" | "light") & {};
    } | {
        type: () => "dark" | "light";
    } | {
        type: ((new (...args: any[]) => ("dark" | "light") & {}) | (() => "dark" | "light"))[];
    }, "default"> & {
        default: "line";
    };
    readonly size: Omit<{
        type: new (...args: any[]) => ("small" | "meduim") & {};
    } | {
        type: () => "small" | "meduim";
    } | {
        type: ((new (...args: any[]) => ("small" | "meduim") & {}) | (() => "small" | "meduim"))[];
    }, "default"> & {
        default: "meduim";
    };
    readonly transitionProps: Omit<{
        type: new (...args: any[]) => (string | Record<string, any>) & {};
    } | {
        type: () => string | Record<string, any>;
    } | {
        type: ((new (...args: any[]) => (string | Record<string, any>) & {}) | (() => string | Record<string, any>))[];
    }, "default"> & {
        default: "visoning-popover";
    };
    readonly showArrow: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly arrowProps: vue_demi.PropType<Record<string, any>>;
    readonly contentProps: vue_demi.PropType<Record<string, any>>;
}, {
    readonly interactions: "hover";
    readonly theme: "drak";
    readonly textAlign: "start";
    readonly allowPointerEnterTarget: false;
}>>>, {
    readonly shift: boolean | _floating_ui_core.ShiftOptions;
    readonly placement: _floating_ui_core.Placement;
    readonly strategy: _floating_ui_core.Strategy;
    readonly disabled: boolean;
    readonly autoUpdate: boolean | UseAutoUpdateOptions;
    readonly interactions: false | Interaction | Interaction[];
    readonly allowPointerEnterTarget: boolean;
    readonly inactiveWhenClickOutside: boolean;
    readonly open: boolean;
    readonly defaultOpen: boolean;
    readonly appendTo: string | false | HTMLElement;
    readonly autoUpdateOnClosed: boolean;
    readonly gpuAcceleration: boolean;
    readonly destoryedOnClosed: boolean;
    readonly theme: "dark" | "light";
    readonly size: "small" | "meduim";
    readonly transitionProps: string | Record<string, any>;
    readonly showArrow: boolean;
    readonly textAlign: "right" | "left" | "start" | "end" | "center" | "justify" | "match-parent";
}>;

interface TooltipExposed extends PopoverExposed {
}
declare type TooltipArrowSlotProps = FloatingData;
declare const TooltipPropsType: {
    /**
     * align tooltip content. enum of CSS text-align.
     * @default 'start'
     */
    readonly textAlign: PropType<"right" | "left" | "start" | "end" | "center" | "justify" | "match-parent">;
    /**
     * HTML attributes of node.
     */
    readonly tooltipProps: PropType<Record<string, any>>;
    /**
     * Custom tooltip node wrapper.
     */
    readonly tooltipWrapper: PropType<(popup: VNode | null) => VNode>;
    readonly onFloatingDataUpdate: PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _visoning_vue_floating_core.Strategy;
        placement: _visoning_vue_floating_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Placement & {};
    } | {
        type: () => _visoning_vue_floating_core.Placement;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Placement & {}) | (() => _visoning_vue_floating_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Strategy & {};
    } | {
        type: () => _visoning_vue_floating_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Strategy & {}) | (() => _visoning_vue_floating_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: PropType<_visoning_vue_floating_core.Middleware[]>;
    readonly arrow: PropType<CreateArrow>;
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: PropType<PopupDelay>;
    readonly clickDelay: PropType<PopupDelay>;
    readonly focusDelay: PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly content: PropType<string | (() => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly theme: Omit<{
        type: new (...args: any[]) => ("dark" | "light") & {};
    } | {
        type: () => "dark" | "light";
    } | {
        type: ((new (...args: any[]) => ("dark" | "light") & {}) | (() => "dark" | "light"))[];
    }, "default"> & {
        default: "line";
    };
    readonly size: Omit<{
        type: new (...args: any[]) => ("small" | "meduim") & {};
    } | {
        type: () => "small" | "meduim";
    } | {
        type: ((new (...args: any[]) => ("small" | "meduim") & {}) | (() => "small" | "meduim"))[];
    }, "default"> & {
        default: "meduim";
    };
    readonly transitionProps: Omit<{
        type: new (...args: any[]) => (string | Record<string, any>) & {};
    } | {
        type: () => string | Record<string, any>;
    } | {
        type: ((new (...args: any[]) => (string | Record<string, any>) & {}) | (() => string | Record<string, any>))[];
    }, "default"> & {
        default: "visoning-popover";
    };
    readonly showArrow: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly arrowProps: PropType<Record<string, any>>;
    readonly contentProps: PropType<Record<string, any>>;
};
declare const TooltipDefaultProps: {
    readonly interactions: "hover";
    readonly theme: "drak";
    readonly textAlign: "start";
    readonly allowPointerEnterTarget: false;
};
declare const TooltipProps: _visoning_vue_utility.WithDefaultProps<{
    /**
     * align tooltip content. enum of CSS text-align.
     * @default 'start'
     */
    readonly textAlign: PropType<"right" | "left" | "start" | "end" | "center" | "justify" | "match-parent">;
    /**
     * HTML attributes of node.
     */
    readonly tooltipProps: PropType<Record<string, any>>;
    /**
     * Custom tooltip node wrapper.
     */
    readonly tooltipWrapper: PropType<(popup: VNode | null) => VNode>;
    readonly onFloatingDataUpdate: PropType<(data: {
        x: number | null;
        y: number | null;
        strategy: _visoning_vue_floating_core.Strategy;
        placement: _visoning_vue_floating_core.Placement;
        middlewareData: {
            [x: string]: any;
            arrow?: {
                x?: number | undefined;
                y?: number | undefined;
                centerOffset: number;
            } | undefined;
            autoPlacement?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            flip?: {
                index?: number | undefined;
                overflows: {
                    placement: _visoning_vue_floating_core.Placement;
                    overflows: number[];
                }[];
            } | undefined;
            hide?: {
                referenceHidden?: boolean | undefined;
                escaped?: boolean | undefined;
                referenceHiddenOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
                escapedOffsets?: {
                    top: number;
                    right: number;
                    bottom: number;
                    left: number;
                } | undefined;
            } | undefined;
            offset?: {
                x: number;
                y: number;
            } | undefined;
            shift?: {
                x: number;
                y: number;
            } | undefined;
        };
    }) => void>;
    readonly 'onUpdate:open': PropType<(open: boolean, info: BaseInteractionInfo<string, Event>) => void>;
    readonly onOpen: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly onClose: PropType<(info: BaseInteractionInfo<string, Event>) => void>;
    readonly shift: Omit<{
        type: new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {};
    } | {
        type: () => boolean | _floating_ui_core.ShiftOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _floating_ui_core.ShiftOptions) & {}) | (() => boolean | _floating_ui_core.ShiftOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly placement: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Placement & {};
    } | {
        type: () => _visoning_vue_floating_core.Placement;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Placement & {}) | (() => _visoning_vue_floating_core.Placement))[];
    }, "default"> & {
        default: "bottom";
    };
    readonly strategy: Omit<{
        type: new (...args: any[]) => _visoning_vue_floating_core.Strategy & {};
    } | {
        type: () => _visoning_vue_floating_core.Strategy;
    } | {
        type: ((new (...args: any[]) => _visoning_vue_floating_core.Strategy & {}) | (() => _visoning_vue_floating_core.Strategy))[];
    }, "default"> & {
        default: "absolute";
    };
    readonly middleware: PropType<_visoning_vue_floating_core.Middleware[]>;
    readonly arrow: PropType<CreateArrow>;
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: Omit<{
        type: new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {};
    } | {
        type: () => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    } | {
        type: ((new (...args: any[]) => (boolean | _visoning_vue_floating_core.UseAutoUpdateOptions) & {}) | (() => boolean | _visoning_vue_floating_core.UseAutoUpdateOptions))[];
    }, "default"> & {
        default: true;
    };
    readonly delay: PropType<PopupDelay>;
    readonly interactions: Omit<{
        type: new (...args: any[]) => (false | Interaction | Interaction[]) & {};
    } | {
        type: () => false | Interaction | Interaction[];
    } | {
        type: ((new (...args: any[]) => (false | Interaction | Interaction[]) & {}) | (() => false | Interaction | Interaction[]))[];
    }, "default"> & {
        default: "hover";
    };
    readonly hoverDelay: PropType<PopupDelay>;
    readonly clickDelay: PropType<PopupDelay>;
    readonly focusDelay: PropType<PopupDelay>;
    readonly allowPointerEnterTarget: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly inactiveWhenClickOutside: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly open: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: undefined;
    };
    readonly defaultOpen: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: false;
    };
    readonly virtualElement: PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: Omit<{
        type: new (...args: any[]) => (string | false | HTMLElement) & {};
    } | {
        type: () => string | false | HTMLElement;
    } | {
        type: ((new (...args: any[]) => (string | false | HTMLElement) & {}) | (() => string | false | HTMLElement))[];
    }, "default"> & {
        default: "body";
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly floatingProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly content: PropType<string | (() => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>)>;
    readonly theme: Omit<{
        type: new (...args: any[]) => ("dark" | "light") & {};
    } | {
        type: () => "dark" | "light";
    } | {
        type: ((new (...args: any[]) => ("dark" | "light") & {}) | (() => "dark" | "light"))[];
    }, "default"> & {
        default: "line";
    };
    readonly size: Omit<{
        type: new (...args: any[]) => ("small" | "meduim") & {};
    } | {
        type: () => "small" | "meduim";
    } | {
        type: ((new (...args: any[]) => ("small" | "meduim") & {}) | (() => "small" | "meduim"))[];
    }, "default"> & {
        default: "meduim";
    };
    readonly transitionProps: Omit<{
        type: new (...args: any[]) => (string | Record<string, any>) & {};
    } | {
        type: () => string | Record<string, any>;
    } | {
        type: ((new (...args: any[]) => (string | Record<string, any>) & {}) | (() => string | Record<string, any>))[];
    }, "default"> & {
        default: "visoning-popover";
    };
    readonly showArrow: Omit<{
        type: BooleanConstructor;
    }, "default"> & {
        default: true;
    };
    readonly arrowProps: PropType<Record<string, any>>;
    readonly contentProps: PropType<Record<string, any>>;
}, {
    readonly interactions: "hover";
    readonly theme: "drak";
    readonly textAlign: "start";
    readonly allowPointerEnterTarget: false;
}>;
declare type TooltipProps = ExtractPropTypes<typeof TooltipProps>;

export { CreateArrow, Popover, PopoverArrowSlotProps, classNames$1 as PopoverClassNames, PopoverDefaultProps, PopoverExposed, PopoverProps, PopoverPropsType, PopoverTransitionName, Popup, PopupDefaultProps, PopupDelay, PopupDelayType, PopupExposed, PopupProps, PopupPropsType, PopupSlotProps, Tooltip, TooltipArrowSlotProps, classNames as TooltipClassNames, TooltipDefaultProps, TooltipExposed, TooltipProps, TooltipPropsType };
